==> kubernetes-model-flowcontrol-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta1/FlowSchemaSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class FlowSchemaSpecBuilder extends io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.FlowSchemaSpecFluentImpl<io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.FlowSchemaSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.FlowSchemaSpec,io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.FlowSchemaSpecBuilder>{
  public FlowSchemaSpecBuilder() {
    this(false);
  }
  public FlowSchemaSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new FlowSchemaSpec(), validationEnabled);
  }
  public FlowSchemaSpecBuilder(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.FlowSchemaSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public FlowSchemaSpecBuilder(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.FlowSchemaSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new FlowSchemaSpec(), validationEnabled);
  }
  public FlowSchemaSpecBuilder(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.FlowSchemaSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.FlowSchemaSpec instance) {
    this(fluent, instance, false);
  }
  public FlowSchemaSpecBuilder(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.FlowSchemaSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.FlowSchemaSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDistinguisherMethod(instance.getDistinguisherMethod()); 
    fluent.withMatchingPrecedence(instance.getMatchingPrecedence()); 
    fluent.withPriorityLevelConfiguration(instance.getPriorityLevelConfiguration()); 
    fluent.withRules(instance.getRules()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public FlowSchemaSpecBuilder(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.FlowSchemaSpec instance) {
    this(instance,false);
  }
  public FlowSchemaSpecBuilder(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.FlowSchemaSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDistinguisherMethod(instance.getDistinguisherMethod()); 
    this.withMatchingPrecedence(instance.getMatchingPrecedence()); 
    this.withPriorityLevelConfiguration(instance.getPriorityLevelConfiguration()); 
    this.withRules(instance.getRules()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.FlowSchemaSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.FlowSchemaSpec build() {
    FlowSchemaSpec buildable = new FlowSchemaSpec(fluent.getDistinguisherMethod(),fluent.getMatchingPrecedence(),fluent.getPriorityLevelConfiguration(),fluent.getRules());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FlowSchemaSpecBuilder that = (FlowSchemaSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-flowcontrol-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta1/FlowSchemaSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class FlowSchemaSpecBuilder extends FlowSchemaSpecFluentImpl<FlowSchemaSpecBuilder> implements VisitableBuilder<FlowSchemaSpec,FlowSchemaSpecBuilder>{
  public FlowSchemaSpecBuilder() {
    this(false);
  }
  public FlowSchemaSpecBuilder(Boolean validationEnabled) {
    this(new FlowSchemaSpec(), validationEnabled);
  }
  public FlowSchemaSpecBuilder(FlowSchemaSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public FlowSchemaSpecBuilder(FlowSchemaSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new FlowSchemaSpec(), validationEnabled);
  }
  public FlowSchemaSpecBuilder(FlowSchemaSpecFluent<?> fluent,FlowSchemaSpec instance) {
    this(fluent, instance, false);
  }
  public FlowSchemaSpecBuilder(FlowSchemaSpecFluent<?> fluent,FlowSchemaSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDistinguisherMethod(instance.getDistinguisherMethod()); 
    fluent.withMatchingPrecedence(instance.getMatchingPrecedence()); 
    fluent.withPriorityLevelConfiguration(instance.getPriorityLevelConfiguration()); 
    fluent.withRules(instance.getRules()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public FlowSchemaSpecBuilder(FlowSchemaSpec instance) {
    this(instance,false);
  }
  public FlowSchemaSpecBuilder(FlowSchemaSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withDistinguisherMethod(instance.getDistinguisherMethod()); 
    this.withMatchingPrecedence(instance.getMatchingPrecedence()); 
    this.withPriorityLevelConfiguration(instance.getPriorityLevelConfiguration()); 
    this.withRules(instance.getRules()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  FlowSchemaSpecFluent<?> fluent;
  Boolean validationEnabled;
  public FlowSchemaSpec build() {
    FlowSchemaSpec buildable = new FlowSchemaSpec(fluent.getDistinguisherMethod(),fluent.getMatchingPrecedence(),fluent.getPriorityLevelConfiguration(),fluent.getRules());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
